#[repr(u8)]pub enum Sstop {
VALUE00 = 0,
VALUE01 = 1,
VALUE10 = 2,
VALUE11 = 3,
}Variants
VALUE00 = 0
Stop bit disabled for transmitter/receiver/match store
VALUE01 = 1
Stop bit disabled for transmitter/receiver/match store, receiver/match store will store receive data on the configured shift edge when timer in stop condition
VALUE10 = 2
Transmitter outputs stop bit value 0 on store, receiver/match store sets error flag if stop bit is not 0, receiver/match store will also store receive data on the configured shift edge when timer in stop condition
VALUE11 = 3
Transmitter outputs stop bit value 1 on store, receiver/match store sets error flag if stop bit is not 1, receiver/match store will also store receive data on the configured shift edge when timer in stop condition
Implementations